==> zio-aws-elasticache_2.12-5.17.104.7-sources.jar: zio/aws/elasticache/model/Authentication.scala <==
package zio.aws.elasticache.model
import java.lang.Integer
import zio.aws.elasticache.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Authentication(
    `type`: Option[zio.aws.elasticache.model.AuthenticationType] = None,
    passwordCount: Option[IntegerOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.Authentication = {
    import Authentication.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.Authentication
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(
        passwordCount.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.passwordCount)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.Authentication.ReadOnly =
    zio.aws.elasticache.model.Authentication.wrap(buildAwsValue())
}
object Authentication {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.Authentication
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.Authentication =
      zio.aws.elasticache.model.Authentication(
        `type`.map(value => value),
        passwordCount.map(value => value)
      )
    def `type`: Option[zio.aws.elasticache.model.AuthenticationType]
    def passwordCount: Option[IntegerOptional]
    def getType
        : ZIO[Any, AwsError, zio.aws.elasticache.model.AuthenticationType] =
      AwsError.unwrapOptionField("type", `type`)
    def getPasswordCount: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("passwordCount", passwordCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.Authentication
  ) extends zio.aws.elasticache.model.Authentication.ReadOnly {
    override val `type`: Option[zio.aws.elasticache.model.AuthenticationType] =
      scala
        .Option(impl.`type`())
        .map(value => zio.aws.elasticache.model.AuthenticationType.wrap(value))
    override val passwordCount: Option[IntegerOptional] = scala
      .Option(impl.passwordCount())
      .map(value => zio.aws.elasticache.model.primitives.IntegerOptional(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.Authentication
  ): zio.aws.elasticache.model.Authentication.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticache_2.12-5.17.153.1-sources.jar: zio/aws/elasticache/model/Authentication.scala <==
package zio.aws.elasticache.model
import java.lang.Integer
import zio.aws.elasticache.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Authentication(
    `type`: Option[zio.aws.elasticache.model.AuthenticationType] = None,
    passwordCount: Option[IntegerOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.Authentication = {
    import Authentication.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.Authentication
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(passwordCount.map(value => value: Integer))(
        _.passwordCount
      )
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.Authentication.ReadOnly =
    zio.aws.elasticache.model.Authentication.wrap(buildAwsValue())
}
object Authentication {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.Authentication
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.Authentication =
      zio.aws.elasticache.model.Authentication(
        `type`.map(value => value),
        passwordCount.map(value => value)
      )
    def `type`: Option[zio.aws.elasticache.model.AuthenticationType]
    def passwordCount: Option[IntegerOptional]
    def getType
        : ZIO[Any, AwsError, zio.aws.elasticache.model.AuthenticationType] =
      AwsError.unwrapOptionField("type", `type`)
    def getPasswordCount: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("passwordCount", passwordCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.Authentication
  ) extends zio.aws.elasticache.model.Authentication.ReadOnly {
    override val `type`: Option[zio.aws.elasticache.model.AuthenticationType] =
      scala
        .Option(impl.`type`())
        .map(value => zio.aws.elasticache.model.AuthenticationType.wrap(value))
    override val passwordCount: Option[IntegerOptional] =
      scala.Option(impl.passwordCount()).map(value => value: IntegerOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.Authentication
  ): zio.aws.elasticache.model.Authentication.ReadOnly = new Wrapper(impl)
}
